pub struct Html;Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Html
impl<'de> Deserialize<'de> for Html
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<Html> for SupportLang
impl From<Html> for SupportLang
Sourceimpl Language for Html
impl Language for Html
Sourcefn expando_char(&self) -> char
fn expando_char(&self) -> char
Some language does not accept $ as the leading char for identifiers.
We need to change $ to other char at run-time to make parser happy, thus the name expando.
By default this is the same as meta_var char so replacement is done at runtime.
Sourcefn pre_process_pattern<'q>(&self, query: &'q str) -> Cow<'q, str>
fn pre_process_pattern<'q>(&self, query: &'q str) -> Cow<'q, str>
normalize pattern code before matching
e.g. remove expression_statement, or prefer parsing {} to object over block
fn kind_to_id(&self, kind: &str) -> u16
fn field_to_id(&self, field: &str) -> Option<u16>
fn build_pattern( &self, builder: &PatternBuilder<'_>, ) -> Result<Pattern, PatternError>
Sourcefn meta_var_char(&self) -> char
fn meta_var_char(&self) -> char
Configure meta variable special character
By default $ is the metavar char, but in PHP it can be #
Sourcefn extract_meta_var(&self, source: &str) -> Option<MetaVariable>
fn extract_meta_var(&self, source: &str) -> Option<MetaVariable>
extract MetaVariable from a given source string
At runtime we need to use expand_char
Sourceimpl LanguageExt for Html
impl LanguageExt for Html
Sourcefn get_ts_language(&self) -> TSLanguage
fn get_ts_language(&self) -> TSLanguage
tree sitter language to parse the source
fn injectable_languages(&self) -> Option<&'static [&'static str]>
Sourcefn extract_injections<L: LanguageExt>(
&self,
root: Node<'_, StrDoc<L>>,
) -> Vec<(String, Vec<TSRange>)>
fn extract_injections<L: LanguageExt>( &self, root: Node<'_, StrDoc<L>>, ) -> Vec<(String, Vec<TSRange>)>
Get injected language regions in the root document. e.g. get JavaScripts in HTML.
Each entry is parsed as an independent tree-sitter document.
Multiple entries for the same language produce separate parse trees.
Also see https://tree-sitter.github.io/tree-sitter/using-parsers#multi-language-documents
impl Copy for Html